@@ -272,10 +272,10 @@ class Model(Base):
 
     def get(self, **kwargs):
         """
-        Gets the model object by loading it from the Fusion Platform<sup>&reg;</sup>. Uses the model's current id and base model id for the get unless explicit values are
-        provided via keyword arguments. This assumes the model is obtained using a GET RESTful request, and that the model data is held with the expected dictionary
-        key within the response. The model is then loaded using the supplied schema to obtain the corresponding Python representation of it, before loading it into
-        the model as a set of read-only attributes.
+        Gets the model object by loading it from the Fusion Platform<sup>&reg;</sup>. Uses the model's current id and base model id for the get unless explicit
+        values are provided via keyword arguments. This assumes the model is obtained using a GET RESTful request, and that the model data is held with the expected
+        dictionary key within the response. The model is then loaded using the supplied schema to obtain the corresponding Python representation of it, before
+        loading it into the model as a set of read-only attributes.
 
         Args:
             kwargs: Any explicit ids to be used.
@@ -509,7 +509,7 @@ class Model(Base):
             # Build the generator around all of the returned items, which must all have been persisted.
             for item in response.get(Model._RESPONSE_KEY_LIST, []):
                 model = cls(session)
-                model.__set_model_from_response(item, **kwargs)
+                model._set_model_from_response(item, **kwargs)
                 model.__persisted = True
 
                 yield model
@@ -543,7 +543,7 @@ class Model(Base):
             modified_response[key] = value
 
         # Load the response into the model. We ignore missing required fields and those which are None.
-        self.__set_model_from_response(modified_response, partial=True)
+        self._set_model_from_response(modified_response, partial=True)
 
         # The model is not persisted.
         self.__persisted = False
@@ -576,7 +576,7 @@ class Model(Base):
             raise ModelError(i18n.t('models.model.failed_model_send_and_load'))
 
         # Load the response into the model.
-        self.__set_model_from_response(response.get(key, {}))
+        self._set_model_from_response(response.get(key, {}))
 
     def __setattr__(self, key, value):
         """
@@ -653,7 +653,7 @@ class Model(Base):
             if Model._METADATA_HIDE not in schema.fields[key].metadata:
                 self.__dict__[key] = value_to_read_only(self.__model[key])
 
-    def __set_model_from_response(self, response, partial=False, **kwargs):
+    def _set_model_from_response(self, response, partial=False, **kwargs):
         """
         Obtains the model from the response using the supplied schema to obtain the corresponding Python representation of it, before
         loading it into the model as a set of read-only attributes.
@@ -683,7 +683,7 @@ class Model(Base):
             message = str(e)
             raise ModelError(i18n.t('models.model.failed_model_validation', message=message)) from e
 
-    def __str__(self):
+    def __repr__(self):
         """
         Returns:
             A string representation of the object.
